==> haskell-concise-0.1.0.1-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concise
version: 0.1.0.1
id: concise-0.1.0.1-Jb86FyeUOPCJZOXNDFguaU
key: concise-0.1.0.1-Jb86FyeUOPCJZOXNDFguaU
license: BSD-3-Clause
copyright: Copyright (C) 2016  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-concise
synopsis: Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.
category: Data, Lenses
abi: 459446087fee526ba97b187d42114e6a
exposed: True
exposed-modules:
    Control.Lens.Cons.Extras
import-dirs: /usr/lib/ghc-8.4.2/site-local/concise-0.1.0.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/concise-0.1.0.1
hs-libraries: HSconcise-0.1.0.1-Jb86FyeUOPCJZOXNDFguaU
depends:
    base-4.11.1.0 lens-4.16.1-FaBtBs35W1AFn0Dujiagj2 text-1.2.3.0
    bytestring-0.10.8.2
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             lens-4.16.1-FaBtBs35W1AFn0Dujiagj2=60a1f41f9a49c8965911673c7537a6ce
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
haddock-interfaces: /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html: /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concise-0.1.0.1-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concise
version: 0.1.0.1
id: concise-0.1.0.1-Azt0ZQCu4go3GE92mamG7x
key: concise-0.1.0.1-Azt0ZQCu4go3GE92mamG7x
license: BSD-3-Clause
copyright: Copyright (C) 2016  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-concise
synopsis: Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.
category: Data, Lenses
abi: 5dbb3aa9922c3bf14f2266e29708f1fd
exposed: True
exposed-modules:
    Control.Lens.Cons.Extras
import-dirs: /usr/lib/ghc-8.4.2/site-local/concise-0.1.0.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/concise-0.1.0.1
hs-libraries: HSconcise-0.1.0.1-Azt0ZQCu4go3GE92mamG7x
depends:
    base-4.11.1.0 lens-4.16.1-Lu0iIErcrywL3MKnmv6KhR text-1.2.3.0
    bytestring-0.10.8.2
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             lens-4.16.1-Lu0iIErcrywL3MKnmv6KhR=905a1b476a76c47c50afaa3dc0b6f349
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
haddock-interfaces: /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html: /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
